# LazyUtils
Repository with diverse implementations so you can reuse on others projects.

Lazy utils was created to have a lot of broad functions and implementations
 that help during the coding. Currently have the following general features:
  - Configuration file
  - File management
  - Persistance local storage feature
  - Secrets management with Local storage
  - Classes structure like Singleton and Callable
  - Randomize function to generate strings
